<h1 style="text-align:center"> Documenting and ML tracking tool</h1> 

## Purpose of the app

- This application is created to do some of the data science development work like documentation, compare supervised ML algorithms using jupyter notebook.

For documentation visit, <a href='https://github.com/anesh-ml/Document-and-ML-track-tool'>this github link</a>
